# 1:1 Meeting Template

Use this template for manager/report one-on-one meetings.

```markdown
# 1:1: [Manager] & [Report] - [Date]

## Meeting Details
**Date**: [Date]
**Last meeting**: <mention-page url="...">Previous 1:1</mention-page>

## Agenda

### [Report]'s Topics
1. [Topic to discuss]
2. [Question or concern]

### [Manager]'s Topics
1. [Topic to cover]
2. [Feedback or update]

## Discussion Notes

### [Topic 1]
[Discussion points]

**Action items**:
- [ ] [Action] - @[Owner]

### [Topic 2]
[Discussion points]

## Career Development

**Current focus**: [Development goal]
**Progress**: [Update on progress]

## Feedback

**What's going well**:
- [Positive feedback]

**Areas for growth**:
- [Developmental feedback]

## Action Items

- [ ] [Action] - @[Report] - Due: [Date]
- [ ] [Action] - @[Manager] - Due: [Date]

## Next Meeting

**Date**: [Date]
**Topics to cover**:
- [Carry-over topic]
- [Upcoming topic]
```

